/* /////////////////////////////////////////////////////////////////////////////
 * File:        reclspp.h
 *
 * Purpose:     recls C++ mapping.
 *
 * Created:     18th August 2003
 * Updated:     23rd September 2003
 *
 * Copyright:   Synesis Software Pty Ltd, (c) 2003. All rights reserved.
 *
 * Author:      Matthew Wilson, Synesis Software Pty Ltd.
 *
 * License:     (Licensed under the Synesis Software Standard Source License)
 *
 *              Copyright (C) 2002-2003, Synesis Software Pty Ltd.
 *
 *              All rights reserved.
 *
 *              www:        http://www.synesis.com.au/software
 *                          http://www.recls.org/
 *
 *              email:      submissions@recls.org  for submissions
 *                          admin@recls.org        for other enquiries
 *
 *              Redistribution and use in source and binary forms, with or
 *              without modification, are permitted provided that the following
 *              conditions are met:
 *
 *              (i) Redistributions of source code must retain the above
 *              copyright notice and contact information, this list of
 *              conditions and the following disclaimer.
 *
 *              (ii) Any derived versions of this software (howsoever modified)
 *              remain the sole property of Synesis Software.
 *
 *              (iii) Any derived versions of this software (howsoever modified)
 *              remain subject to all these conditions.
 *
 *              (iv) Neither the name of Synesis Software nor the names of any
 *              subdivisions, employees or agents of Synesis Software, nor the
 *              names of any other contributors to this software may be used to
 *              endorse or promote products derived from this software without
 *              specific prior written permission.
 *
 *              This source code is provided by Synesis Software "as is" and any
 *              warranties, whether expressed or implied, including, but not
 *              limited to, the implied warranties of merchantability and
 *              fitness for a particular purpose are disclaimed. In no event
 *              shall the Synesis Software be liable for any direct, indirect,
 *              incidental, special, exemplary, or consequential damages
 *              (including, but not limited to, procurement of substitute goods
 *              or services; loss of use, data, or profits; or business
 *              interruption) however caused and on any theory of liability,
 *              whether in contract, strict liability, or tort (including
 *              negligence or otherwise) arising in any way out of the use of
 *              this software, even if advised of the possibility of such
 *              damage.
 *
 * ////////////////////////////////////////////////////////////////////////// */


#ifndef RECLS_INCL_H_RECLSPP
#define RECLS_INCL_H_RECLSPP

/* File version */
#ifndef RECLS_DOCUMENTATION_SKIP_SECTION
# define RECLS_VER_H_RECLSPP_MAJOR      1
# define RECLS_VER_H_RECLSPP_MINOR      0
# define RECLS_VER_H_RECLSPP_REVISION   5
# define RECLS_VER_H_RECLSPP_EDIT       5
#endif /* !RECLS_DOCUMENTATION_SKIP_SECTION */

/** \file reclspp.h The root header for the \ref group_recls_cpp "recls C++ mapping" */

/* /////////////////////////////////////////////////////////////////////////////
 * Includes
 */

#include <recls.h>

#ifdef RECLS_CPP_STRING_HEADER
# include RECLS_CPP_STRING_HEADER
#else
# include <string>
#endif /* RECLS_STRING_HEADER */

/* /////////////////////////////////////////////////////////////////////////////
 * Namespace
 */

#if !defined(RECLS_NO_NAMESPACE)
namespace recls
{

namespace cpp
{
#endif /* !RECLS_NO_NAMESPACE */

/* /////////////////////////////////////////////////////////////////////////////
 * Typedefs
 */

#ifdef RECLS_DOCUMENTATION_SKIP_SECTION

/// \brief string_t The string type to be used in the \c reclspp (\c recls::cpp) namespace
///
/// \ingroup group_recls_cpp
/// 
/// \note By default \c string_t is defined to be <code>std::string</code>, but this can be
/// overridden by specifying \c RECLS_CPP_STRING_HEADER, e.g. <code>"mystring.h"</code>,
/// <b>and</b> also defining \c RECLS_CPP_STRING_T, e.g. <code>"my_string"</code> which will
/// be typedef'd to \c string_t
typedef std::string             string_t;

#else /* ? RECLS_DOCUMENTATION_SKIP_SECTION */

# ifdef RECLS_CPP_STRING_HEADER
#  ifndef RECLS_CPP_STRING_T
#   error RECLS_CPP_STRING_T must be defined when RECLS_CPP_STRING_HEADER is defined
#  endif /* !RECLS_STRING_T */
typedef RECLS_CPP_STRING_T      string_t;
# else
#  if defined(RECLS_COMPILER_IS_DMC)
typedef string                  string_t;
#  else
typedef std::string             string_t;
#  endif /* RECLS_COMPILER_IS_DMC */
# endif /* RECLS_STRING_HEADER */
#endif /* RECLS_DOCUMENTATION_SKIP_SECTION */

/* /////////////////////////////////////////////////////////////////////////////
 * Namespace
 */

#if !defined(RECLS_NO_NAMESPACE)
} /* namespace cpp */
} /* namespace recls */
namespace reclspp = ::recls::cpp;
#endif /* !RECLS_NO_NAMESPACE */

/* ////////////////////////////////////////////////////////////////////////// */

#endif /* !RECLS_INCL_H_RECLSPP */

/* ////////////////////////////////////////////////////////////////////////// */
